@@ -7,9 +7,8 @@ Example Usage::
     addressbook = capnp.load('addressbook.capnp')
 
     # Building
-    message = capnp.MallocMessageBuilder()
-    addressBook = message.initRoot(addressbook.AddressBook)
-    people = addressBook.init('people', 1)
+    addresses = addressbook.AddressBook.newMessage()
+    people = addresses.init('people', 1)
 
     alice = people[0]
     alice.id = 123
@@ -19,21 +18,22 @@ Example Usage::
     alicePhone.type = 'mobile'
 
     f = open('example.bin', 'w')
-    capnp.writePackedMessageToFd(f.fileno(), message)
+    addresses.writeTo(f)
     f.close()
 
     # Reading
     f = open('example.bin')
-    message = capnp.PackedFdMessageReader(f.fileno())
 
-    addressBook = message.getRoot(addressbook.AddressBook)
+    addresses = addressbook.AddressBook.readFrom(f)
 
-    for person in addressBook.people:
+    for person in addresses.people:
         print(person.name, ':', person.email)
         for phone in person.phones:
             print(phone.type, ':', phone.number)
 """
 from .version import version as __version__
 from .capnp import *
-from .capnp import _DynamicStructReader, _DynamicStructBuilder, _DynamicResizableListBuilder, _DynamicListReader, _DynamicListBuilder, _DynamicOrphan, _DynamicResizableListBuilder
+from .capnp import _DynamicStructReader, _DynamicStructBuilder, _DynamicResizableListBuilder, _DynamicListReader, _DynamicListBuilder, _DynamicOrphan, _DynamicResizableListBuilder, _MallocMessageBuilder, _PackedFdMessageReader, _StreamFdMessageReader, _write_message_to_fd, _write_packed_message_to_fd
 del capnp
+
+add_import_hook() # enable import hook by default
