@@ -10,4 +10,15 @@ T fixMaybe(::kj::Maybe<T> val) {
   } else {
     throw std::invalid_argument("member was null");
   }
+}
+
+template<typename T>
+const char * getEnumString(T val) {
+
+  auto maybe_val = val.which();
+  KJ_IF_MAYBE(new_val, maybe_val) {
+    return new_val->getProto().getName().cStr();;
+  } else {
+    return "";
+  }
 }
\ No newline at end of file
