@@ -1,6 +1,7 @@
 import pytest
 import capnp
 import os
+import sys
 
 this_dir = os.path.dirname(__file__)
 
@@ -27,10 +28,10 @@ def test_classes(addressbook):
     assert addressbook.Person
 
 def test_import(foo, bar):
-    m = capnp.MallocMessageBuilder()
-    foo = m.initRoot(foo.Foo)
-    m2 = capnp.MallocMessageBuilder()
-    bar = m2.initRoot(bar.Bar)
+    m = capnp._MallocMessageBuilder()
+    foo = m.init_root(foo.Foo)
+    m2 = capnp._MallocMessageBuilder()
+    bar = m2.init_root(bar.Bar)
 
     foo.name = 'foo'
     bar.foo = foo
@@ -44,12 +45,39 @@ def test_failed_import():
     foo = s.load(os.path.join(this_dir, 'foo.capnp'))
     bar = s2.load(os.path.join(this_dir, 'bar.capnp'))
 
-    m = capnp.MallocMessageBuilder()
-    foo = m.initRoot(foo.Foo)
-    m2 = capnp.MallocMessageBuilder()
-    bar = m2.initRoot(bar.Bar)
+    m = capnp._MallocMessageBuilder()
+    foo = m.init_root(foo.Foo)
+    m2 = capnp._MallocMessageBuilder()
+    bar = m2.init_root(bar.Bar)
 
     foo.name = 'foo'
 
     with pytest.raises(ValueError):
         bar.foo = foo
+
+def test_defualt_import_hook():
+    import addressbook_capnp
+
+def test_add_import_hook():
+    capnp.add_import_hook([this_dir])
+
+    import addressbook_capnp
+    addressbook_capnp.AddressBook.new_message()
+
+def test_multiple_add_import_hook():
+    capnp.add_import_hook()
+    capnp.add_import_hook()
+    capnp.add_import_hook([this_dir])
+
+    import addressbook_capnp
+    addressbook_capnp.AddressBook.new_message()
+
+def test_remove_import_hook():
+    capnp.add_import_hook([this_dir])
+    capnp.remove_import_hook()
+
+    if 'addressbook_capnp' in sys.modules:
+        del sys.modules['addressbook_capnp'] # hack to deal with it being imported already
+
+    with pytest.raises(ImportError):
+        import addressbook_capnp
